@@ -19,10 +19,10 @@
 #' object. If one wishes to incorporate semilandmarks, GPA can either be performed first using gpagen,
 #' or within bilat.symmetry by passing adequate GPA arguments (i.e. curves, surfaces, ProcD etc, 
 #' see \code{\link{gpagen}}. If a geomorphShapes object is provided, semilandmarks are automatically 
-#' identified and slid during GPA. For "object.sym = FALSE, landmarks should be of dimension (p x k 
+#' identified and slid during GPA. For object.sym = FALSE, landmarks should be of dimension (p x k 
 #' x 2n), as each specimen is represented by both left and right configurations.
 #'    
-#' Analyses of symmetry for matched pairs of objects is implemented when {object.sym=FALSE}. Here, 
+#' Analyses of symmetry for matched pairs of objects is implemented when object.sym = FALSE. Here, 
 #' a 3D array [p x k x 2n] contains the landmark coordinates for all pairs of structures (2 
 #' structures for each of n specimens). Because the two sets of structures are on opposite sides,
 #' they represent mirror images, and one set must be reflected prior to the analysis to allow 
@@ -33,7 +33,7 @@
 #' specimen may also be included in the dataset, and when specified will be used as measurement 
 #' error (see Klingenberg and McIntyre 1998). 
 #' 
-#' Analyses of object symmetry is implemented when {object.sym=TRUE}. Here, a 3D array [p x k x n] 
+#' Analyses of object symmetry is implemented when object.sym = TRUE. Here, a 3D array [p x k x n] 
 #' contains the landmark coordinates for all n specimens. To obtain information about asymmetry, 
 #' the function generates a second set of objects by reflecting them about one of their coordinate 
 #' axes. The landmarks across the line of symmetry are then relabeled to obtain landmark 
@@ -80,7 +80,7 @@
 #' @param replicate An optional vector designating which objects belong to which group of replicates.
 #' Alternatively, this can be a character value to indicate the name of the variable in the data frame to use.
 #' @param object.sym A logical value specifying whether the analysis should proceed based on object 
-#' symmetry {=TRUE} or matching symmetry {=FALSE}
+#' symmetry = TRUE or matching symmetry = FALSE
 #' @param land.pairs An optional matrix (for object symmetry) containing numbers for matched pairs 
 #' of landmarks across the line of symmetry 
 #' @param data A data frame for the function environment, see \code{\link{geomorph.data.frame}}. It 
@@ -146,51 +146,53 @@
 #' canalization, developmental stability, modularity, and allometry in lizard head shape. The American
 #' Naturalist 185:44–58.
 #' @examples
+#' \dontrun{
+#' 
 #' #Example of matching symmetry
-#' # NOT RUN
-#' # data(mosquito)
-#' # gdf <- geomorph.data.frame(wingshape = mosquito$wingshape, 
-#' # ind=mosquito$ind, 
-#' # side=mosquito$side,
-#' # replicate=mosquito$replicate)
-#' # mosquito.sym <- bilat.symmetry(A = wingshape, ind = ind, side = side,
-#' # replicate = replicate, object.sym = FALSE, RRPP = TRUE, iter = 149, 
-#' # data = gdf)
-#' # summary(mosquito.sym)
-#' # plot(mosquito.sym, warpgrids = TRUE)
-#' # mosquito.sym$shape.anova # extract just the anova table on shape
+#' data(mosquito)
+#' gdf <- geomorph.data.frame(wingshape = mosquito$wingshape, 
+#' ind = mosquito$ind, 
+#' side = mosquito$side,
+#' replicate = mosquito$replicate)
+#' mosquito.sym <- bilat.symmetry(A = wingshape, ind = ind, side = side,
+#' replicate = replicate, object.sym = FALSE, RRPP = TRUE, 
+#' data = gdf)
+#' summary(mosquito.sym)
+#' plot(mosquito.sym, warpgrids = TRUE)
+#' mosquito.sym$shape.anova # extract just the anova table on shape
 #' 
 #' # Previous example, performing GPA first
-#' # Y.gpa <- gpagen(mosquito$wingshape)
-#' # mosquito.sym2 <- bilat.symmetry(A = Y.gpa, ind = ind, side = side,
-#' # replicate = replicate, object.sym = FALSE, RRPP = TRUE, iter = 149, 
-#' # data = gdf)
-#' # summary(mosquito.sym2)
-#' # summary(mosquito.sym) # same results
+#' Y.gpa <- gpagen(mosquito$wingshape)
+#' mosquito.sym2 <- bilat.symmetry(A = Y.gpa, ind = ind, side = side,
+#' replicate = replicate, object.sym = FALSE, RRPP = TRUE, 
+#' data = gdf)
+#' summary(mosquito.sym2)
+#' summary(mosquito.sym) # same results
 #'
 #' #Example of object symmetry
 #'
-#' # data(lizards)
-#' # gdf <- geomorph.data.frame(shape = lizards$coords, 
-#' # ind = lizards$ind, 
-#' # replicate = lizards$rep)
-#' # liz.sym <- bilat.symmetry(A = shape, ind = ind, rep = rep, 
-#' # object.sym = TRUE, 
-#' # land.pairs = lizards$lm.pairs, data = gdf, RRPP = TRUE, iter = 149)
-#' # summary(liz.sym)
+#' data(lizards)
+#' gdf <- geomorph.data.frame(shape = lizards$coords, 
+#' ind = lizards$ind, 
+#' replicate = lizards$rep)
+#' liz.sym <- bilat.symmetry(A = shape, ind = ind, rep = rep, 
+#' object.sym = TRUE, 
+#' land.pairs = lizards$lm.pairs, data = gdf, RRPP = TRUE)
+#' summary(liz.sym)
 #' 
 #' # Example of object symmetry in 3D and including semilandmarks
 #' 
-#' # data(scallops)
-#' # gdf <- geomorph.data.frame(shape = scallops$coorddata, 
-#' # ind = scallops$ind)
-#' # scallop.sym <- bilat.symmetry(A = shape, ind = ind, 
-#' # object.sym = TRUE, 
-#' # curves= scallops$curvslide, surfaces = scallops$surfslide,
-#' # land.pairs=scallops$land.pairs, data = gdf, RRPP = TRUE, iter = 149)
-#' # summary(scallop.sym)
+#' data(scallops)
+#' gdf <- geomorph.data.frame(shape = scallops$coorddata, 
+#' ind = scallops$ind)
+#' scallop.sym <- bilat.symmetry(A = shape, ind = ind, 
+#' object.sym = TRUE, 
+#' curves= scallops$curvslide, surfaces = scallops$surfslide,
+#' land.pairs=scallops$land.pairs, data = gdf, RRPP = TRUE)
+#' summary(scallop.sym)
 #' # NOTE one can also: plot(scallop.sym, warpgrids = TRUE, mesh = NULL)
 #' # NOTE one can also: scallop.sym$data.type # recall the symmetry type
+#' }
 
 bilat.symmetry <- function(A, ind = NULL, side = NULL, replicate = NULL, object.sym = FALSE, land.pairs = NULL,
                            data = NULL, iter = 999, seed = NULL, RRPP = TRUE, SS.type = c("I", "II", "III"),
@@ -318,16 +320,20 @@ bilat.symmetry <- function(A, ind = NULL, side = NULL, replicate = NULL, object.
   # build shape components for output
   X.ind <- model.matrix(~ind + 0, data = as.data.frame(dat.shape[-1]))
   symm.component <- arrayspecs(coef(lm.fit(X.ind, Y)),p,k)
+  ind.names <- substr(dimnames(symm.component)[[3]], start=4,
+                      stop=nchar(dimnames(symm.component)[[3]]))
+  dimnames(symm.component)[[3]] <- ind.names
   X.side <- model.matrix(~(side:ind) + 0, data = as.data.frame(dat.shape[-1]))
   avg.side.symm <- coef(lm.fit(X.side, Y))
   n.ind <- nlevels(ind)
   n.side <- nlevels(side)
   indsq <- seq(n.side, (n.ind*n.side), n.side)
-  asymm.component <- avg.side.symm[indsq,] - avg.side.symm[-indsq,]
+  asymm.component <- avg.side.symm[-indsq,] - avg.side.symm[indsq,]
   mn.shape <- mshape(A)
   asymm.component <- simplify2array(lapply(1:n.ind, function(j) {
     t(matrix(asymm.component[j,],k,p)) + mn.shape
   }))
+  
   dimnames(asymm.component)[[3]] <- dimnames(symm.component)[[3]]
   DA.est <- coef(.lm.fit(X.side, Y))
   DA.mns <- arrayspecs(rbind(apply(DA.est[-indsq,], 2, mean), apply(DA.est[indsq,], 2, mean)), p, k)
