@@ -3,7 +3,7 @@
 #' Function plots landmark coordinates for a set of specimens
 #'
 #' The function creates a plot of the landmark coordinates for all specimens. This is useful for examining 
-#'  patterns of variation in Procrustes shape variables, after a GPA has been performed. If "mean=TRUE", the mean shape will be calculated and added to the plot.
+#'  patterns of variation in Procrustes shape variables, after a GPA has been performed. If "mean = TRUE", the mean shape will be calculated and added to the plot.
 #'  Additionally, if a matrix of links is provided, the landmarks of the mean shape will be connected by lines.  
 #'  The link matrix is an m x 2 matrix, where m is the desired number of links. Each row of the link matrix 
 #'  designates the two landmarks to be connected by that link. The function will plot either two- or 
@@ -13,17 +13,19 @@
 #' @param mean A logical value indicating whether the mean shape should be included in the plot
 #' @param links An optional matrix defining for links between landmarks (only if mean=TRUE)
 #' @param label A logical value indicating whether landmark numbers will be plotted (only if mean=TRUE)
-#' @param plot.param A list of plot parameters for the points (pt.bg, pt.cex), mean (mean.bg, mean.cex), links (link.col, link.lwd, link.lty) and landmark labels (txt.cex, txt.adj, txt.pos, txt.col)
+#' @param plot_param A list of plot parameters for the points (pt.bg, pt.cex), mean (mean.bg, mean.cex), links (link.col, link.lwd, link.lty) and landmark labels (txt.cex, txt.adj, txt.pos, txt.col)
 #' @export
 #' @keywords visualization
 #' @author Dean Adams
 #' @seealso  \code{\link[rgl]{rgl-package}} (used in 3D plotting)
 #' @examples
+#' \dontrun{
 #' data(plethodon) 
-#' Y.gpa<-gpagen(plethodon$land)    #GPA-alignment
+#' Y.gpa <- gpagen(plethodon$land)    #GPA-alignment
 #'
-#' plotAllSpecimens(Y.gpa$coords,links=plethodon$links)
-plotAllSpecimens<-function(A,mean=TRUE,links=NULL,label=FALSE,plot.param = list()){
+#' plotAllSpecimens(Y.gpa$coords, links = plethodon$links)
+#' }
+plotAllSpecimens<-function(A,mean=TRUE,links=NULL,label=FALSE,plot_param = list()){
   if (length(dim(A))!=3){
     stop("Data matrix not a 3D array (see 'arrayspecs').")  }
   if(any(is.na(A))==T){
@@ -31,7 +33,7 @@ plotAllSpecimens<-function(A,mean=TRUE,links=NULL,label=FALSE,plot.param = list(
   k<-dim(A)[2]
   if(mean==TRUE){ mn<-mshape(A) }
   
-  p.p <- plot.param
+  p.p <- plot_param
   if(is.null(p.p$pt.bg)) p.p$pt.bg="gray" ; if(is.null(p.p$pt.cex)) p.p$pt.cex=1 ; 
   if(is.null(p.p$mean.bg)) p.p$mean.bg="black" ; if(is.null(p.p$mean.cex)) p.p$mean.cex=2
   if(is.null(p.p$link.col)) p.p$link.col="black" ; if(is.null(p.p$link.lwd)) p.p$link.lwd=2
