@@ -57,19 +57,19 @@
 #' 
 #' The following are brief descriptions of the different plotting methods, with references.
 #' 
-#'\itemize{
-#'   \item {If "method = PredLine" (the default) the function calculates fitted values from a \code{\link{procD.lm}} fit, and 
+#'\describe{
+#'   \item{"method = PredLine"}{calculates fitted values from a \code{\link{procD.lm}} fit, and 
 #'   plots the first principal component of the "predicted" values versus size as a stylized graphic of the 
 #'   allometric trend (Adams and Nistri 2010). This method is based on linear models and 
 #'   can allow for other model variable to be incorporated.}
-#'   \item {If "method = RegScore" the function calculates standardized shape scores 
+#'   \item{"method = RegScore"}{calculates standardized shape scores 
 #'   from the regression of shape on size, and plots these versus size (Drake and Klingenberg 2008). 
 #'   For a single allometry, these shape scores are mathematically identical to the CAC (Adams et al. 2013).  
 #'   This method is based on linear models and can allow for other model variable to be incorporated.}
-#'   \item {If "method = size.shape" the function perform principal components analysis on a data space containing both shape 
+#'   \item{"method = size.shape"}{performs principal components analysis on a data space containing both shape 
 #'   and size (sensu Mitteroecker et al. 2004).  This method is not based on linear models and results will not be changed by 
 #'   changing the allometry model.}
-#'   \item {If "method = CAC"  the function calculates the 
+#'   \item{"method = CAC"}{calculates the 
 #'   common allometric component of the shape data, which is an estimate of the average allometric trend 
 #'   for group-mean centered data (Mitteroecker et al. 2004). The function also calculates the residual shape component (RSC) for 
 #'   the data.  This method is not based on linear models and results will not be changed by 
@@ -106,14 +106,14 @@
 #' Systematic Biology 49: 740-753.
 #' 
 #' @examples 
-#' 
+#' \dontrun{
 #' # Simple allometry
 #' data(plethodon) 
 #' Y.gpa <- gpagen(plethodon$land, print.progress = FALSE)    #GPA-alignment  
 #' 
 #' gdf <- geomorph.data.frame(Y.gpa, site = plethodon$site, 
 #' species = plethodon$species) 
-#' fit <- procD.lm(coords ~ log(Csize), data=gdf, iter=0, 
+#' fit <- procD.lm(coords ~ log(Csize), data = gdf, 
 #' print.progress = FALSE)
 #' 
 #' # Predline
@@ -142,7 +142,7 @@
 #' plot(PLS)
 #' 
 #' # Group Allometries
-#' fit <- procD.lm(coords ~ Csize * species * site, data=gdf, iter=0, 
+#' fit <- procD.lm(coords ~ Csize * species * site, data = gdf, 
 #' print.progress = FALSE)
 #' 
 #' # CAC (should not change from last time; model change has no effect)
@@ -166,13 +166,13 @@
 #' 
 #' # Are species' shape differences just a manifestation of shape allometry?
 #' 
-#' fit3 <- procD.lm(coords ~ species, data = gdf, iter = 0, 
+#' fit3 <- procD.lm(coords ~ species, data = gdf, 
 #' print.progress = FALSE)
 #' plotAllometry(fit3, size = gdf$Csize, logsz = TRUE, method = "RegScore", 
 #' pch = 19, col = as.numeric(gdf$species))
 #' 
 #' # No evidence this is the case
-#' 
+#' }
 plotAllometry <- function(fit, size, logsz = TRUE, 
         method = c("PredLine", "RegScore", "size.shape", "CAC"), ...){
   method <- match.arg(method)
@@ -240,30 +240,30 @@ plotAllometry <- function(fit, size, logsz = TRUE,
         if(method == "CAC") {
           
           par(mfcol = c(1,2))
-          plot.args <- list(x = xc, y = CAC,
+          plot_args <- list(x = xc, y = CAC,
                             xlab = if(logsz) "log(Size)" else "Size",
                             ylab = "CAC", ...)
-          plot2.args <- list(x = CAC, y = RSC[, 1],
+          plot2_args <- list(x = CAC, y = RSC[, 1],
                              xlab = "CAC", ylab = "RSC1", ...)
-          do.call(plot, plot.args)
-          do.call(plot, plot2.args)
+          do.call(plot, plot_args)
+          do.call(plot, plot2_args)
           par(mfcol = c(1,1))
-          out <- list(CAC = CAC, RSC = RSC, plot.args = plot.args,
-                      all.plot.args = list(CAC=plot.args, RSC = plot2.args))
+          out <- list(CAC = CAC, RSC = RSC, plot_args = plot_args,
+                      all.plot_args = list(CAC=plot_args, RSC = plot2_args))
         }
         
         if(method == "size.shape") {
           
           v <- round(PCA$sdev^2/sum(PCA$sdev^2) * 100, 2)
-          plot.args <- list(x = PC.points[,1], y = PC.points[,2],
+          plot_args <- list(x = PC.points[,1], y = PC.points[,2],
                             xlab = paste("PC 1: ", v[1], "%", sep = ""), 
                             ylab = paste("PC 2: ", v[2], "%", sep = ""),
                             ...)
-          do.call(plot, plot.args)
+          do.call(plot, plot_args)
           title("Size-Shape PC plot")
           
           out <- list(size.shape.PCA = PCA,
-                      PC.points = PC.points, plot.args = plot.args)
+                      PC.points = PC.points, plot_args = plot_args)
         }
       }
   
